# Copyright (C) 2012-2013 Peter Hatina <phatina@redhat.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

class LMIShellCache(object):
    """
    Class representing a LMIShell cache. Currently, it caches retrieved classes from the
    CIMOM.
    """
    def __init__(self, active=True, classname_list=None, classes=None):
        """
        Constructs a LMIShellCache object.

        Arguments:
            active -- bool flag, if the cache is active
            classname_list -- list of cached class names
            classes -- dictionary with cached CIMClass objects, where the key is the class
                name and value is CIMClass object
        """
        self._classname_list = classname_list
        self._classes = classes if not classes is None else {}
        self._active = active

    def clear(self):
        """
        Clears the cache.
        """
        self._classname_list = None
        self._classes = {}

    def get_classes(self):
        """
        Returns the list of cached class names' list.
        """
        return self._classname_list

    def set_classes(self, classname_list):
        """
        Stores a new class names' list.
        """
        self._classname_list = classname_list

    def get_class(self, classname):
        """
        Returns a cached CIMClass object, if proper class name provided, otherwise returns
        None.

        Arguments:
            classname -- string containing a cached class name
        """
        if not classname in self._classes:
            return None
        return self._classes[classname]

    def add_class(self, cim_class):
        """
        Stores a new CIMClass object into the cache.

        Arguments:
            cim_class -- CIMClass object
        """
        self._classes[cim_class.classname] = cim_class

    @property
    def active(self):
        """
        Property returning, if the cache is active.
        """
        return self._active

    @active.setter
    def active(self, val):
        """
        Property setter for the property active.
        """
        self._active = val
